Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1549)

Unified Diff: chrome/browser/tab_contents/tab_contents.cc

Issue 3413027: Force accelerated 2d canvas off for chrome ui (Closed)
Patch Set: Created 10 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/tab_contents/tab_contents.cc
diff --git a/chrome/browser/tab_contents/tab_contents.cc b/chrome/browser/tab_contents/tab_contents.cc
index 1d702bd78ae465c94d40eed541af3c0ef99f9b3b..2c6b9389a1646102035e39981980bd0eefd8b184 100644
--- a/chrome/browser/tab_contents/tab_contents.cc
+++ b/chrome/browser/tab_contents/tab_contents.cc
@@ -2875,11 +2875,12 @@ WebPreferences TabContents::GetWebkitPrefs() {
WebPreferences web_prefs =
RenderViewHostDelegateHelper::GetWebkitPrefs(profile, is_dom_ui);
// Force accelerated compositing off for chrome: and chrome-extension:
// pages.
if (GetURL().SchemeIs(chrome::kChromeUIScheme) ||
GetURL().SchemeIs(chrome::kExtensionScheme)) {
web_prefs.accelerated_compositing_enabled = false;
+ web_prefs.accelerated_2d_canvas_enabled = false;
}
#if defined(OS_MACOSX)
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -2875,11 +2875,12 @@ WebPreferences TabContents::GetWebkitPrefs() {
WebPreferences web_prefs =
RenderViewHostDelegateHelper::GetWebkitPrefs(profile, is_dom_ui);
- // Force accelerated compositing off for chrome: and chrome-extension:
- // pages.
+ // Force accelerated compositing and 2d canvas off for chrome: and
+ // chrome-extension: pages.
if (GetURL().SchemeIs(chrome::kChromeUIScheme) ||
GetURL().SchemeIs(chrome::kExtensionScheme)) {

Powered by Google App Engine
This is Rietveld 408576698